@@ -1651,7 +1651,9 @@ proc filexfer::mimetype {file} {
     } else {
         set mtype application/octet-stream
     }
-
+    if { $mtype == "application/xml" } {
+        return [list "text/plain" "ascii"]
+    }
     if {[string match text/* $mtype]} {
         set aorb "ascii"
     } else {
